pub enum Wrap {
Repeat,
MirroredRepeat,
ClampToEdge,
ClampToBorder,
}Expand description
Wrap mode
Variants
Repeat
Repeats the texture by ignoring the integer part of the coordinate.
MirroredRepeat
Repeats the texture and mirrors it, when the integer part of the coordinate is odd.
ClampToEdge
The coordinate will be clamped between 0 and 1.
ClampToBorder
Coordinates outside the range [0.0, 1.0] will be given a border color.